==> haskell-uuid-1.3.13-19-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-uuid.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uuid
version: 1.3.13
id: uuid-1.3.13-GARGmob9iiyCx4aQMRWy6
key: uuid-1.3.13-GARGmob9iiyCx4aQMRWy6
license: BSD-3-Clause
copyright: (c) 2008-2014 Antoine Latter
maintainer: hvr@gnu.org
author: Antoine Latter
homepage: https://github.com/hvr/uuid
synopsis: For creating, comparing, parsing and printing Universally Unique Identifiers
description:
    This library is useful for creating, comparing, parsing and
    printing Universally Unique Identifiers.
    .
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.
category: Data
abi: d9ba578b201bc5d6cb9910c2c6fe8112
exposed: True
exposed-modules:
    Data.UUID Data.UUID.Util Data.UUID.V1 Data.UUID.V3 Data.UUID.V4
    Data.UUID.V5
hidden-modules: Data.UUID.Named Data.Word.Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/uuid-1.3.13
library-dirs: /usr/lib/ghc-8.4.3/site-local/uuid-1.3.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/uuid-1.3.13
hs-libraries: HSuuid-1.3.13-GARGmob9iiyCx4aQMRWy6
depends:
    base-4.11.1.0 binary-0.8.5.1 bytestring-0.10.8.2
    cryptohash-sha1-0.11.100.1-Edd5keIcG8RLy8uxn1ueOe
    cryptohash-md5-0.11.100.1-C9GYF44B4VH54L80n64dS7
    entropy-0.4.1.3-DgdrwWh8SPxKScPoc17aKl
    network-info-0.2.0.10-Jad1urRPRS69Kkzc04cakY
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV time-1.8.0.2 text-1.2.3.0
    uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             cryptohash-sha1-0.11.100.1-Edd5keIcG8RLy8uxn1ueOe=afb3380b25ce679d1843c0e409adf53b
             cryptohash-md5-0.11.100.1-C9GYF44B4VH54L80n64dS7=5236cc6b0c5edb80dd40335491d9d792
             entropy-0.4.1.3-DgdrwWh8SPxKScPoc17aKl=f8adc9fd931aa49b6a2a7e2785fb0c69
             network-info-0.2.0.10-Jad1urRPRS69Kkzc04cakY=e4c11d4adc765b10cd34d01d706ceb77
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71=073bf76fdf6ac46f8363958226adfe9d
haddock-interfaces: /usr/share/doc/haskell-uuid/html/uuid.haddock
haddock-html: /usr/share/doc/haskell-uuid/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uuid-1.3.13-20-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-uuid.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uuid
version: 1.3.13
id: uuid-1.3.13-BzhnnbR7T3EGOKYVZphlKC
key: uuid-1.3.13-BzhnnbR7T3EGOKYVZphlKC
license: BSD-3-Clause
copyright: (c) 2008-2014 Antoine Latter
maintainer: hvr@gnu.org
author: Antoine Latter
homepage: https://github.com/hvr/uuid
synopsis: For creating, comparing, parsing and printing Universally Unique Identifiers
description:
    This library is useful for creating, comparing, parsing and
    printing Universally Unique Identifiers.
    .
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.
category: Data
abi: 11152e5aa9a1f5459c1c8769b0d419fb
exposed: True
exposed-modules:
    Data.UUID Data.UUID.Util Data.UUID.V1 Data.UUID.V3 Data.UUID.V4
    Data.UUID.V5
hidden-modules: Data.UUID.Named Data.Word.Util
import-dirs: /usr/lib/ghc-8.6.1/site-local/uuid-1.3.13
library-dirs: /usr/lib/ghc-8.6.1/site-local/uuid-1.3.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/uuid-1.3.13
hs-libraries: HSuuid-1.3.13-BzhnnbR7T3EGOKYVZphlKC
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2
    cryptohash-md5-0.11.100.1-4xpVEo8eyQi2XbS8mfTUTa
    cryptohash-sha1-0.11.100.1-FedZHhK3zTs7eOQXIrPeso
    entropy-0.4.1.3-IxkqMjuefoT8uP0p0wmXuD
    network-info-0.2.0.10-Hvah5LTyr9qJHUikKEcv5M
    random-1.1-3ypV4EIycgb35PKjTYYr5q text-1.2.3.1 time-1.8.0.2
    uuid-types-1.0.3-1r1IBIU9fBZK1eE2MZEQJb
haddock-interfaces: /usr/share/doc/haskell-uuid/html/uuid.haddock
haddock-html: /usr/share/doc/haskell-uuid/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
